Class: SnapDeploy::Provider::Heroku::API::OauthClient

Inherits:
Object
  • Object
show all
Defined in:
lib/snap_deploy/provider/heroku/api.rb

Overview

OAuth clients are applications that Heroku users can authorize to automate, customize or extend their usage of the platform. For more information please refer to the Heroku OAuth documentation.

Instance Method Summary collapse

Constructor Details

#initialize(client) ⇒ OauthClient

Returns a new instance of OauthClient.



1070
1071
1072
# File 'lib/snap_deploy/provider/heroku/api.rb', line 1070

def initialize(client)
  @client = client
end

Instance Method Details

#create(body) ⇒ Object

Create a new OAuth client.

Parameters:

  • body:

    the object to pass as the request payload



1077
1078
1079
# File 'lib/snap_deploy/provider/heroku/api.rb', line 1077

def create(body)
  @client.oauth_client.create(body)
end

#delete(oauth_client_id) ⇒ Object

Delete OAuth client.

Parameters:

  • oauth_client_id:

    unique identifier of this OAuth client



1084
1085
1086
# File 'lib/snap_deploy/provider/heroku/api.rb', line 1084

def delete(oauth_client_id)
  @client.oauth_client.delete(oauth_client_id)
end

#info(oauth_client_id) ⇒ Object

Info for an OAuth client

Parameters:

  • oauth_client_id:

    unique identifier of this OAuth client



1091
1092
1093
# File 'lib/snap_deploy/provider/heroku/api.rb', line 1091

def info(oauth_client_id)
  @client.oauth_client.info(oauth_client_id)
end

#listObject

List OAuth clients



1096
1097
1098
# File 'lib/snap_deploy/provider/heroku/api.rb', line 1096

def list()
  @client.oauth_client.list()
end

#update(oauth_client_id, body) ⇒ Object

Update OAuth client

Parameters:

  • oauth_client_id:

    unique identifier of this OAuth client

  • body:

    the object to pass as the request payload



1104
1105
1106
# File 'lib/snap_deploy/provider/heroku/api.rb', line 1104

def update(oauth_client_id, body)
  @client.oauth_client.update(oauth_client_id, body)
end