Class: SnapDeploy::Provider::Heroku::API::OauthClient
- Inherits:
-
Object
- Object
- SnapDeploy::Provider::Heroku::API::OauthClient
- Defined in:
- lib/snap_deploy/provider/heroku/api.rb
Overview
OAuth clients are applications that Heroku users can authorize to automate, customize or extend their usage of the platform. For more information please refer to the Heroku OAuth documentation.
Instance Method Summary collapse
-
#create(body) ⇒ Object
Create a new OAuth client.
-
#delete(oauth_client_id) ⇒ Object
Delete OAuth client.
-
#info(oauth_client_id) ⇒ Object
Info for an OAuth client.
-
#initialize(client) ⇒ OauthClient
constructor
A new instance of OauthClient.
-
#list ⇒ Object
List OAuth clients.
-
#update(oauth_client_id, body) ⇒ Object
Update OAuth client.
Constructor Details
#initialize(client) ⇒ OauthClient
Returns a new instance of OauthClient.
1070 1071 1072 |
# File 'lib/snap_deploy/provider/heroku/api.rb', line 1070 def initialize(client) @client = client end |
Instance Method Details
#create(body) ⇒ Object
Create a new OAuth client.
1077 1078 1079 |
# File 'lib/snap_deploy/provider/heroku/api.rb', line 1077 def create(body) @client.oauth_client.create(body) end |
#delete(oauth_client_id) ⇒ Object
Delete OAuth client.
1084 1085 1086 |
# File 'lib/snap_deploy/provider/heroku/api.rb', line 1084 def delete(oauth_client_id) @client.oauth_client.delete(oauth_client_id) end |
#info(oauth_client_id) ⇒ Object
Info for an OAuth client
1091 1092 1093 |
# File 'lib/snap_deploy/provider/heroku/api.rb', line 1091 def info(oauth_client_id) @client.oauth_client.info(oauth_client_id) end |
#list ⇒ Object
List OAuth clients
1096 1097 1098 |
# File 'lib/snap_deploy/provider/heroku/api.rb', line 1096 def list() @client.oauth_client.list() end |
#update(oauth_client_id, body) ⇒ Object
Update OAuth client
1104 1105 1106 |
# File 'lib/snap_deploy/provider/heroku/api.rb', line 1104 def update(oauth_client_id, body) @client.oauth_client.update(oauth_client_id, body) end |